@@ -443,6 +443,7 @@ sub channel_receive
 {
     my ($kernel, $heap, $request) = @_[KERNEL, HEAP, ARG0];
 
+    DEBUG && warn "$$: Recieved data...\n";
     # we won't trust the other end to set this properly
     $request->{errors_to}={ kernel=>$heap->{remote_kernel},
                             session=>'IKC',
@@ -463,6 +464,7 @@ sub channel_send
 {
     my ($heap, $request)=@_[HEAP, ARG0];
 
+    DEBUG && warn "$$: Sending data...\n";
         # add our name so the foreign channel can find us
         # TODO should we do this?  or should the other end do this?
     $request->{rsvp}->{kernel}||=$heap->{kernel_name}
@@ -476,7 +478,7 @@ sub channel_send
 sub channel_close
 {
     my ($heap)=$_[HEAP];
-#    warn "$heap channel_close\n";
+    DEBUG && warn "$$: channel_close\n";
     delete $heap->{'wheel_client'};
 }
 
