@@ -167,11 +167,12 @@ sub ping
 sub disconnect
 {
     my($self)=@_;
-    $self->post('IKC/unregister', $self->{name});
+    $self->post('IKC/unregister', $self->{name}) if $self->{remote};
     delete @{$self->{remote}}{qw(socket connected name aliases)};
+    $self->{remote}={};
 }
 
-sub DISTROY 
+sub DESTROY 
 {
     my($self)=@_;
     $self->disconnect;
@@ -187,8 +188,16 @@ sub END
 sub post
 {
     my($self, $spec, $params)=@_;
-    $spec="poe://$self->{remote}{name}/$spec" 
-                                      unless ref $spec or $spec=~m(^poe:);
+    unless(ref $spec or $spec=~m(^poe:)) {
+        
+        unless($self->{remote}{name}) {
+            $error="Attempting to post $spec to unknown kernel";
+            carp $error;
+            return;
+        }
+
+        $spec="poe://$self->{remote}{name}/$spec";
+    }
 
     my $ret=eval { 
         return 0 if(0==$self->_try_send({event=>$spec, params=>$params}));
@@ -261,7 +270,7 @@ sub _try_send
     DEBUG && print "Sending message...\n";
     if(defined $ret and $ret==0)
     {
-        return unless $self->connect();
+        return 0 unless $self->connect();
         DEBUG && print "Retry message...\n";
         $ret=$self->_send_msg($msg);
     }
